@@ -1,9 +1,8 @@
 
 import numpy as np
-import paddle
 
 from .abc_interpreter import Interpreter
-from ..data_processor.readers import preprocess_inputs, preprocess_save_path
+from ..data_processor.readers import images_transform_pipeline, preprocess_save_path
 from ..data_processor.visualizer import explanation_to_vis, show_vis_explanation, save_image
 
 
@@ -15,21 +14,20 @@ class GradCAMInterpreter(Interpreter):
     https://arxiv.org/abs/1610.02391
     """
 
-    def __init__(self,
-                 paddle_model,
-                 use_cuda=True,
-                 device='gpu:0',
-                 model_input_shape=[3, 224, 224]) -> None:
+    def __init__(
+        self,
+        paddle_model: callable,
+        use_cuda: bool=True,
+        device: str='gpu:0'
+    ):
         """
 
         Args:
             paddle_model (callable): A model with ``forward`` and possibly ``backward`` functions.
             device (str): The device used for running `paddle_model`, options: ``cpu``, ``gpu:0``, ``gpu:1`` etc.
             use_cuda (bool):  Would be deprecated soon. Use ``device`` directly.
-            model_input_shape (list, optional): The input shape of the model. Default: [3, 224, 224]
         """
         Interpreter.__init__(self, paddle_model, device, use_cuda)
-        self.model_input_shape = model_input_shape
         self.paddle_prepared = False
 
         # init for usages during the interpretation.
@@ -37,26 +35,33 @@ class GradCAMInterpreter(Interpreter):
         self._feature_maps = {}
 
     def interpret(self,
-                  inputs,
-                  target_layer_name,
-                  label=None,
-                  visual=True,
-                  save_path=None):
+                  inputs: str or list(str) or np.ndarray,
+                  target_layer_name: str,
+                  label: list or np.ndarray=None,
+                  resize_to=224, 
+                  crop_to=None,
+                  visual: bool=True,
+                  save_path=None) -> np.ndarray:
         """
         Main function of the interpreter.
 
         Args:
             inputs (str or list of strs or numpy.ndarray): The input image filepath or a list of filepaths or numpy array of read images.
             target_layer_name (str): The target layer to calculate gradients.
-            labels (list or tuple or numpy.ndarray, optional): The target labels to analyze. The number of labels should be equal to the number of images. If None, the most likely label for each image will be used. Default: None
+            labels (list or tuple or numpy.ndarray, optional): The target labels to analyze. 
+                The number of labels should be equal to the number of images. If None, the most likely label for each image will be used. Default: None
+            resize_to (int, optional): [description]. Images will be rescaled with the shorter edge being `resize_to`. Defaults to 224.
+            crop_to ([type], optional): [description]. After resize, images will be center cropped to a square image with the size `crop_to`. 
+                If None, no crop will be performed. Defaults to None.
             visual (bool, optional): Whether or not to visualize the processed image. Default: True
-            save_path (str or list of strs or None, optional): The filepath(s) to save the processed image(s). If None, the image will not be saved. Default: None
+            save_path (str or list of strs or None, optional): The filepath(s) to save the processed image(s). 
+                If None, the image will not be saved. Default: None
 
         Returns:
             [numpy.ndarray]: interpretations/heatmap for images
         """
 
-        imgs, data = preprocess_inputs(inputs, self.model_input_shape)
+        imgs, data = images_transform_pipeline(inputs, resize_to, crop_to)
         bsz = len(data)  # batch size
         save_path = preprocess_save_path(save_path, bsz)
 
@@ -99,6 +104,7 @@ class GradCAMInterpreter(Interpreter):
 
     def _paddle_prepare(self, predict_fn=None):
         if predict_fn is None:
+            import paddle
             paddle.set_device(self.device)
             # to get gradients, the ``train`` mode must be set.
             # we cannot set v.training = False for the same reason.
